@@ -9,14 +9,16 @@ import (
 	"os"
 	"path/filepath"
 
+	"github.com/go-git/go-git/v5"
 	"github.com/joho/godotenv"
 	"github.com/otiai10/copy"
 	"github.com/spf13/afero"
-	"gopkg.in/src-d/go-git.v4"
 
 	log "github.com/sirupsen/logrus"
 
 	"github.com/stripe/stripe-cli/pkg/config"
+	"github.com/stripe/stripe-cli/pkg/validators"
+
 	g "github.com/stripe/stripe-cli/pkg/git"
 	gitpkg "github.com/stripe/stripe-cli/pkg/git"
 	"github.com/stripe/stripe-cli/pkg/stripe"
@@ -31,6 +33,9 @@ type SampleConfig struct {
 	Integrations    []SampleConfigIntegration `json:"integrations"`
 }
 
+// TestPublishableKeyPlaceholder is the placeholder for empty publishable key in the .env file
+const TestPublishableKeyPlaceholder = "pk_test..."
+
 // HasIntegrations returns true if the sample has multiple integrations
 func (sc *SampleConfig) HasIntegrations() bool {
 	return len(sc.Integrations) > 1
@@ -305,7 +310,7 @@ func (s *SampleManager) Copy(target string) error {
 func ConfigureDotEnv(ctx context.Context, config *config.Config) (map[string]string, error) {
 	publishableKey, _ := config.Profile.GetPublishableKey(false)
 	if publishableKey == "" {
-		return nil, fmt.Errorf("we could not set the publishable key in the .env file; please set this manually or login again to set it automatically next time")
+		publishableKey = TestPublishableKeyPlaceholder
 	}
 
 	apiKey, err := config.Profile.GetAPIKey(false)
@@ -376,6 +381,10 @@ func (s *SampleManager) WriteDotEnv(ctx context.Context, sampleLocation string)
 		if err != nil {
 			return err
 		}
+
+		if envVars["STRIPE_PUBLISHABLE_KEY"] == TestPublishableKeyPlaceholder {
+			return validators.ErrPubKeyNotConfigured
+		}
 	}
 
 	return nil
